@@ -728,7 +728,8 @@ QList<QDate> CalendarSupport::workDays(const QDate &startDate, const QDate &endD
     }
 
     if (KCalPrefs::instance()->mExcludeHolidays) {
-        for (const QString &regionStr : qAsConst(KCalPrefs::instance()->mHolidays)) {
+        const QStringList holidays = KCalPrefs::instance()->mHolidays;
+        for (const QString &regionStr : holidays) {
             KHolidays::HolidayRegion region(regionStr);
             if (region.isValid()) {
                 const KHolidays::Holiday::List list = region.holidays(startDate, endDate);
@@ -751,7 +752,8 @@ QStringList CalendarSupport::holiday(const QDate &date)
     QStringList hdays;
 
     bool showCountryCode = (KCalPrefs::instance()->mHolidays.count() > 1);
-    for (const QString &regionStr : qAsConst(KCalPrefs::instance()->mHolidays)) {
+    const QStringList holidays = KCalPrefs::instance()->mHolidays;
+    for (const QString &regionStr : holidays) {
         KHolidays::HolidayRegion region(regionStr);
         if (region.isValid()) {
             const Holiday::List list = region.holidays(date);
